Skip to contents

A data frame with 8511 rows and 5 columns, containing all the votes cast for every tagging proposal in proposals marked as "Approved", "Rejected", "Proposed" and "Cancelled" (currently consisting of 812 different proposals). This dataset is generated by the function get_proposals_votes(), ran from the script data-raw/tagging_proposals.R.

Usage

proposals_votes

Format

columns:

url

(factor, string) the URL to the tagging proposal wiki page.

votes_raw

a string with the wiki page containing the proposal.

vote

(factor) vote type (approve, abstain, oppose).

user

(factor) voter's username

date_vote

(POSIXct, UTC) date and time in which the vote was cast.